{{- define "cortex" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "cortex") | nindent 2 }}
tags:
  {{- if .Values.cortexDev.memcached.enabled }}
  blocks-storage-memcached: true
  {{- end }}
# The ingress template from the Cortex helm chart uses the networking.k8s.io/v1 API version,
# which is available since v1.19. We have to support v1.18 still, so explicitly disable ingress
# to make sure that when we decide to enable ingress for Cortex we check compatibility between
# supported Kubernetes versions and ingress template.
ingress:
  enabled: false
alertmanager:
  enabled: true
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "alertmanager"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  statefulSet:
    enabled: true
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexAlertmanager") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 2Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexAlertManager }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexAlertmanager" }}
  extraVolumes:
  - name: tmp
    emptyDir: {}
  extraVolumeMounts:
  - mountPath: /tmp
    name: tmp

ruler:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "ruler"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexRuler" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexRuler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

distributor:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "distributor"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexDistributor" }}
  extraArgs:
    distributor.ingestion-rate-limit: {{ .Values.cortexDev.ingestion.rateLimit | quote }}
    distributor.ingestion-burst-size: {{ .Values.cortexDev.ingestion.burstSize | quote }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexDistributor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

ingester:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "ingester"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  extraAgrs:
    blocks-storage.tsdb.retention-period: {{ .Values.cortexDev.retentionTime.ingester }}
  statefulSet:
    enabled: true
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexIngester") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 16Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexIngester }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexIngester }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexIngester }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexIngester" }}

compactor:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexCompactor" }}
  extraAgrs:
    compactor.blocks-retention-period: {{ .Values.cortexDev.retentionTime.compactor }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    enabled: true
    size: 16Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexCompactor }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexCompactor") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}

querier:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "querier"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  extraArgs:
    querier.query-ingesters-within: {{ .Values.cortexDev.retentionTime.ingester }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQuerier" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQuerier") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

query_frontend:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "query-frontend"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQueryFrontend" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQueryFrontend") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

store_gateway:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "store-gateway"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexStoreGateway" }}
  persistentVolume:
    enabled: true
    size: 2Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexStoreGateway }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexStoreGateway") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}

nginx:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "cortex"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "nginx"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  enabled: true
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "nginx") | nindent 4 }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexNginx" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexNginx") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

config:
  server:
    log_level: debug
  storage:
    engine: blocks
  blocks_storage:
    bucket_store:
      bucket_index:
        enabled: true
      sync_dir: /data/tsdb-sync
    {{- if .Values.cortexDev.memcached.enabled }}
      chunks_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks:11211
      index_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks-index:11211
      metadata_cache:
        backend: memcached
        memcached:
          addresses: cortex-memcached-blocks-metadata:11211
    {{- end }}
    tsdb:
      dir: /data/tsdb
    backend: s3
    s3:
      bucket_name: cortex-blocks
      endpoint: "minio:9000"
      access_key_id: {{ include "minio.userAccessKeyId" . | quote }}
      secret_access_key: {{ include "minio.userSecretAccessKey" . | quote }}
      insecure: true
      signature_version: v2
  store_gateway:
    sharding_enabled: true
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  distributor:
{{- if .Values.highAvailabilityEnabled }}
    ha_tracker:
      enable_ha_tracker: true
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/ha-tracker/"
{{- end }}
    ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  ingester:
    lifecycler:
      ring:
{{- if .Values.highAvailabilityEnabled }}
        replication_factor: 3
{{- else }}
        replication_factor: 1
{{- end }}
        kvstore:
          store: etcd
          etcd:
            tls_enabled: false
            tls_insecure_skip_verify: false
            endpoints: ["etcd:2379"]
          prefix: "cortex/collectors/"
  compactor:
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/collectors/"
  ruler:
    enable_api: true
    enable_sharding: true
    enable_alertmanager_v2: true
    ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/rulers/"
  ruler_storage:
    backend: s3
    s3:
      endpoint: "minio:9000"
      access_key_id: {{ include "minio.userAccessKeyId" . | quote }}
      secret_access_key: {{ include "minio.userSecretAccessKey" . | quote }}
      insecure: true
      signature_version: v2
      bucket_name: cortex-notify
  alertmanager:
    enable_api: true
    sharding_enabled: true
    sharding_ring:
      kvstore:
        store: etcd
        etcd:
          tls_enabled: false
          tls_insecure_skip_verify: false
          endpoints: ["etcd:2379"]
        prefix: "cortex/alertmanagers/"
  alertmanager_storage:
    backend: s3
    s3:
      endpoint: "minio:9000"
      access_key_id: {{ include "minio.userAccessKeyId" . | quote }}
      secret_access_key: {{ include "minio.userSecretAccessKey" . | quote }}
      insecure: true
      signature_version: v2
      bucket_name: cortex-notify
{{- end -}}
