{{- define "iamProxy.common" -}}
global:
  dockerBaseUrl: {{ .Values.global.dockerBaseUrl }}
{{- if .Values.global.serviceAnnotations }}
  serviceAnnotations:
    {{- toYaml .Values.global.serviceAnnotations | nindent 4 }}
{{- end }}
# The ingress templates from the iam-proxy helm chart use the extensions/v1beta1 API version,
# which is available till v1.22. For safety, explicitly disable ingresses to make sure that
# when we decide to enable ingress for iam-proxy we check compatibility between supported
# Kubernetes versions and ingress templates.
api:
  ingress:
    api:
      enabled: false
    registration:
      enabled: false
    web:
      enabled: false
service:
  type: LoadBalancer
  {{- if .Values.iam.tls.enabled }}
  port: 443
  {{- else }}
  port: 80
  {{- end }}
oauth2:
  discoveryUrl: "{{ .Values.iam.url }}/auth/realms/iam"
  client:
    id: "{{ .Values.iam.client }}"
  providerCASecretName: "{{ .Values.iam.oidcCASecret }}"
  providerCASecretChecksum: "{{ .Values.iam.oidcCASecretChecksum }}"
  tls:
    enabled: {{ .Values.iam.tls.enabled }}
    clientCertificateControllerEnabled: {{ .Values.iam.tls.clientCertificateControllerEnabled }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- end -}}

{{- define "iamProxy.alertaOverride" -}}
{{- /*
  TODO: Add Cortex-specific roles when PRODX-20570 is merged
*/}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "iamProxyAlerta" }}
oauth2:
  tls:
    certsSecretName: "iam-proxy-alerta-tls-certs"
  {{- if .Values.cortexDev.enabled }}
  upstreams: ["http://cortex-ruler:8080"]
  {{- else }}
  upstreams: ["http://alerta"]
  {{- end }}
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:alerta@{{ .Values.iam.role }}
    - m:sl:{{ .Values.iam.clusterId }}@{{ .Values.iam.componentWideRole }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxyAlerta") | fromYaml }}
{{- if hasKey .Values.resources "iamProxy" }}
  {{- $iamProxyResources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") | fromYaml }}
  {{- $resources = merge $iamProxyResources $resources }}
{{- end }}
{{ $resources | toYaml }}
{{- end -}}

{{- define "iamProxy.alerta" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertaOverride := include "iamProxy.alertaOverride" . | fromYaml }}
{{- merge $iamProxyAlertaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.alertmanagerOverride" -}}
{{- /*
  TODO: Add Cortex-specific roles when PRODX-20570 is merged
*/}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "iamProxyAlertmanager" }}
oauth2:
  tls:
    certsSecretName: "iam-proxy-alertmanager-tls-certs"
  {{- if .Values.cortexDev.enabled }}
  upstreams: ["http://cortex-alertmanager:8080"]
  {{- else }}
  upstreams: ["http://prometheus-alertmanager"]
  {{- end }}
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:alertmngmt@{{ .Values.iam.role }}
    - m:sl:{{ .Values.iam.clusterId }}@{{ .Values.iam.componentWideRole }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxyAlertmanager") | fromYaml }}
{{- if hasKey .Values.resources "iamProxy" }}
  {{- $iamProxyResources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") | fromYaml }}
  {{- $resources = merge $iamProxyResources $resources }}
{{- end }}
{{ $resources | toYaml }}
{{- end -}}

{{- define "iamProxy.alertmanager" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertmanagerOverride := include "iamProxy.alertmanagerOverride" . | fromYaml }}
{{- merge $iamProxyAlertmanagerOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.grafanaOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "iamProxyGrafana" }}
oauth2:
  tls:
    certsSecretName: "iam-proxy-grafana-tls-certs"
  upstreams: ["http://grafana"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:grafana@{{ .Values.iam.role }}
    - m:sl:{{ .Values.iam.clusterId }}@{{ .Values.iam.componentWideRole }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxyGrafana") | fromYaml }}
{{- if hasKey .Values.resources "iamProxy" }}
  {{- $iamProxyResources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") | fromYaml }}
  {{- $resources = merge $iamProxyResources $resources }}
{{- end }}
{{ $resources | toYaml }}
{{- end -}}

{{- define "iamProxy.grafana" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyGrafanaOverride := include "iamProxy.grafanaOverride" . | fromYaml }}
{{- merge $iamProxyGrafanaOverride $iamProxyCommon | toYaml }}
{{- end -}}

# TODO(PRODX-22685): replace Kibana with OpenSearch Dashboards
{{- define "iamProxy.opensearchDashboardsOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "iamProxyOpenSearchDashboards" }}
oauth2:
  tls:
    certsSecretName: "iam-proxy-kibana-tls-certs"
  upstreams: ["http://opensearch-dashboards"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:kibana@{{ .Values.iam.role }}
    - m:sl:{{ .Values.iam.clusterId }}@{{ .Values.iam.componentWideRole }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxyKibana" "fallbackService" "iamProxyOpenSearchDashboards") | fromYaml }}
{{- if hasKey .Values.resources "iamProxy" }}
  {{- $iamProxyResources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") | fromYaml }}
  {{- $resources = merge $iamProxyResources $resources }}
{{- end }}
{{ $resources | toYaml }}
{{- end -}}

{{- define "iamProxy.opensearchDashboards" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $opensearchDashboardsOverride := include "iamProxy.opensearchDashboardsOverride" . | fromYaml }}
{{- merge $opensearchDashboardsOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.prometheusOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "iamProxyPrometheus" }}
oauth2:
  tls:
    certsSecretName: "iam-proxy-prometheus-tls-certs"
  upstreams: ["http://prometheus-server"]
  roles:
    - m:sl:{{ .Values.iam.clusterId }}:pm@{{ .Values.iam.role }}
    - m:sl:{{ .Values.iam.clusterId }}@{{ .Values.iam.componentWideRole }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxyPrometheus") | fromYaml }}
{{- if hasKey .Values.resources "iamProxy" }}
  {{- $iamProxyResources := include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") | fromYaml }}
  {{- $resources = merge $iamProxyResources $resources }}
{{- end }}
{{ $resources | toYaml }}
{{- end -}}

{{- define "iamProxy.prometheus" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyPrometheusOverride := include "iamProxy.prometheusOverride" . | fromYaml }}
{{- merge $iamProxyPrometheusOverride $iamProxyCommon | toYaml }}
{{- end -}}
