{{- define "memcached.common" -}}
image:
  {{- $image := include "stacklight.getImage" (dict "root" . "image" "memcached") | fromYaml }}
  {{- $repo := splitn "/" 2 (index $image "repository") }}
  {{- $_ := set $image "registry" $repo._0 }}
  {{- $_ := set $image "repository" $repo._1 }}
  {{- $image | toYaml | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
podAntiAffinityPreset: hard
architecture: high-availability
{{- else }}
podAntiAffinityPreset: soft
architecture: standalone
{{- end }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "memcached") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "memcached") }}
persistence:
  enabled: {{ .Values.cortexDev.memcached.persistent }}
  size: {{ .Values.cortexDev.memcached.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.memcached }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.memcached }}
    {{- $storageClass = .Values.storage.componentStorageClasses.memcached }}
  {{- end }}
global:
  storageClass: "{{ $storageClass }}"
{{- end }}
{{- end -}}

{{- define "memcached.cortexOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "memcachedBlocks" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedBlocks") }}
{{- end -}}

{{- define "memcached.cortex" -}}
{{- $common := include "memcached.common" . | fromYaml }}
{{- $override := include "memcached.cortexOverride" . | fromYaml }}
{{- merge $override $common | toYaml }}
{{- end -}}

{{- define "memcached.cortexIndexOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "memcachedBlocksIndex" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedBlocksIndex") }}
{{- end -}}

{{- define "memcached.cortex-index" -}}
{{- $common := include "memcached.common" . | fromYaml }}
{{- $override := include "memcached.cortexIndexOverride" . | fromYaml }}
{{- merge $override $common | toYaml }}
{{- end -}}

{{- define "memcached.cortexMetadataOverride" -}}
replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "memcachedBlocksMetadata" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "memcachedBlocksMetadata") }}
{{- end -}}

{{- define "memcached.cortex-metadata" -}}
{{- $common := include "memcached.common" . | fromYaml }}
{{- $override := include "memcached.cortexMetadataOverride" . | fromYaml }}
{{- merge $override $common | toYaml }}
{{- end -}}
