{{- define "mimir" -}}
nameOverride: mimir
mimir:
  config: |
    multitenancy_enabled: false
    limits:
      ruler_max_rules_per_rule_group: 400
    activity_tracker:
      filepath: /data/metrics-activity.log
    alertmanager:
      data_dir: '/data'
      enable_api: true
      external_url: '/alertmanager'
      fallback_config_file: /opt/mimir/fallback.yml
    alertmanager_storage:
      backend: s3
      s3:
        endpoint: minio:9000
        bucket_name: mimir-ruler
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true
    frontend_worker:
      frontend_address: {{ "{{ template \"mimir.fullname\" . }}-query-frontend-headless:{{ include \"mimir.serverGrpcListenPort\" . }}" }}
    ruler:
      enable_api: true
      rule_path: '/data'
      alertmanager_url: dnssrvnoa+http://_http-metrics._tcp.{{ "{{ template \"mimir.fullname\" . }}" }}-alertmanager-headless/alertmanager
    server:
      grpc_server_max_recv_msg_size: 104857600
      grpc_server_max_send_msg_size: 104857600
      grpc_server_max_concurrent_streams: 1000
    frontend:
      log_queries_longer_than: 10s
      align_queries_with_step: true
    compactor:
      data_dir: "/data"
    ingester:
      ring:
        final_sleep: 0s
        num_tokens: 512
    ingester_client:
      grpc_client_config:
        max_recv_msg_size: 104857600
        max_send_msg_size: 104857600
    runtime_config:
      file: /var/{{ "{{ include \"mimir.name\" . }}" }}/runtime.yaml
    memberlist:
      abort_if_cluster_join_fails: false
      compression_enabled: false
      join_members:
      - {{ "{{ include \"mimir.fullname\" . }}" }}-gossip-ring
    blocks_storage:
      backend: s3
      tsdb:
        dir: /data/tsdb
      bucket_store:
        sync_dir: /data/tsdb-sync
        {{- if .Values.cortexDev.memcached.enabled }}
        chunks_cache:
          backend: memcached
          memcached:
            addresses: cortex-memcached-blocks:11211
            max_item_size: {{ "{{ .Values.memcached.maxItemMemory }}" }}
        index_cache:
          backend: memcached
          memcached:
            addresses: cortex-memcached-blocks-index:11211
            max_item_size: {{ "{{ (index .Values \"memcached-queries\").maxItemMemory }}" }}
        metadata_cache:
          backend: memcached
          memcached:
            addresses: cortex-memcached-blocks-metadata:11211
            max_item_size: {{ "{{ (index .Values \"memcached-metadata\").maxItemMemory }}" }}
        {{- end }}
      s3:
        endpoint: minio:9000
        bucket_name: mimir-tsdb
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true
    ruler_storage:
      backend: s3
      s3:
        endpoint: minio:9000
        bucket_name: mimir-ruler
        access_key_id: {{ include "minio.userAccessKeyId" . }}
        secret_access_key: {{ include "minio.userSecretAccessKey" . }}
        insecure: true

alertmanager:
  enabled: true
  extraVolumes:
  - name: alertmanager-config
    configMap:
      name: stacklight-ng-alertmanager
      items:
      - key: fallback.yml
        path: fallback.yml
  extraVolumeMounts:
  - name: alertmanager-config
    mountPath: /opt/mimir
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexAlertmanager" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexAlertmanager") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    size: 10Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexAlertManager }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexAlertManager }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}

compactor:
  replicas: 1
  extraArgs:
    compactor.blocks-retention-period: {{ .Values.cortexDev.retentionTime.compactor }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexCompactor }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexCompactor }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}

distributor:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexDistributor" }}
  persistentVolume:
    size: 20Gi
  extraArgs:
    distributor.ingestion-rate-limit: {{ .Values.cortexDev.ingestion.rateLimit | quote }}
    distributor.ingestion-burst-size: {{ .Values.cortexDev.ingestion.burstSize | quote }}

ingester:
  {{- if .Values.highAvailabilityEnabled }}
  affinity:
    podAntiAffinity:
      requiredDuringSchedulingIgnoredDuringExecution:
      - labelSelector:
          matchExpressions:
          - key: app.kubernetes.io/name
            operator: In
            values:
            - "mimir"
          - key: app.kubernetes.io/component
            operator: In
            values:
            - "ingester"
        topologyKey: "kubernetes.io/hostname"
  {{- end }}
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexIngester" }}
  extraArgs:
    blocks-storage.tsdb.retention-period: {{ .Values.cortexDev.retentionTime.ingester }}
    ingester.ring.replication-factor: 2
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexIngester") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  persistentVolume:
    size: 50Gi
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexIngester }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexIngester }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexIngester }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}
overrides_exporter:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "mimirOverridesExporter" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "mimirOverridesExporter") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

querier:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQuerier" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQuery") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

query_frontend:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexQueryFrontend" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexQueryFrontend") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

ruler:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexRuler" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexRuler") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateless") | indent 2 }}

store_gateway:
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexStoreGateway" }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "cortexStoreGateway") | indent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "cortexStateful") | indent 2 }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.cortexStoreGateway }}
    {{- $storageClass = .Values.storage.componentStorageClasses.cortexStoreGateway }}
  {{- end }}
    storageClass: "{{ $storageClass }}"
{{- end }}

nginx:
  enabled: true
  replicas: {{ get (include "stacklight.replicas" . | fromYaml) "cortexNginx" }}
# Disable creating MinIO by Mimir chart
minio:
  enabled: false
{{- end -}}
