{{- define "minio" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "minioServer") | nindent 2 }}
mcImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "minioClient") | nindent 2 }}
replicas: {{ get (include "stacklight.replicas" . | fromYaml) "minio" }}
{{- if .Values.highAvailabilityEnabled }}
mode: distributed
drivesPerNode: 2
{{- else }}
mode: standalone
{{- end }}
extraArgs: []
rootUser: admin
rootPassword: password
persistence:
  enabled: true
  size: {{ .Values.cortexDev.minio.persistentVolumeClaimSize }}
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.minio }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.minio }}
    {{- $storageClass = .Values.storage.componentStorageClasses.minio }}
  {{- end }}
  storageClass: "{{ $storageClass }}"
{{- end }}
# The ingress templates from the minio 3.1.4 helm chart use the extensions/v1beta1 API version,
# which is available till v1.22. For safety, explicitly disable ingresses to make sure that
# when we decide to enable ingress for minio we check compatibility between supported
# Kubernetes versions and ingress templates.
ingress:
  enabled: false
consoleIngress:
  enabled: false
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") }}
affinity:
  podAntiAffinity:
{{- if .Values.highAvailabilityEnabled }}
    requiredDuringSchedulingIgnoredDuringExecution:
    - topologyKey: "kubernetes.io/hostname"
      labelSelector:
        matchExpressions:
        - key: app
          operator: In
          values:
          - minio
        - key: release
          operator: In
          values:
          - minio
{{- else }}
    preferredDuringSchedulingIgnoredDuringExecution:
    - weight: 100
      podAffinityTerm:
        topologyKey: "kubernetes.io/hostname"
        labelSelector:
          matchExpressions:
          - key: app
            operator: In
            values:
            - minio
          - key: release
            operator: In
            values:
            - minio
{{- end }}
securityContext:
  enabled: false
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minio") }}
users:
- accessKey: {{ include "minio.userAccessKeyId" . }}
  secretKey: {{ include "minio.userSecretAccessKey" . }}
  policy: readwrite
makeUserJob:
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minioMakeUser") | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
buckets:
{{- if .Values.cortexDev.mimir }}
- name: mimir-tsdb
  policy: none
  purge: false
- name: mimir-ruler
  policy: none
  purge: false
{{- else }}
- name: cortex-blocks
  policy: none
  purge: false
- name: cortex-notify
  policy: none
  purge: false
{{- end }}
makeBucketJob:
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "minioMakeBucket") | nindent 2 }}
  {{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
  {{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "minio") | nindent 2 }}
environment: {}
podDisruptionBudget:
  enabled: {{ .Values.highAvailabilityEnabled }}
{{- end -}}

{{/*
MinIO user credentials
*/}}
{{- define "minio.userAccessKeyId" -}}
{{- if .Values.cortexDev.mimir }}mimir{{- else }}cortex{{- end }}
{{- end -}}

{{- define "minio.userSecretAccessKey" -}}
{{- if .Values.cortexDev.mimir }}mimir123{{- else }}cortex123{{- end }}
{{- end -}}
