{{- define "opensearch.server" -}}
{{/* https://logging.apache.org/log4j/2.x/log4j-api/apidocs/org/apache/logging/log4j/Level.html */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "TRACE" "debug" "DEBUG" "info" "INFO" "warn" "WARN" "error" "ERROR" "crit" "FATAL") "component" "elasticsearch" "fallbackComponent" "opensearch" | include "stacklight.logLevel" -}}
clusterName: "opensearch"
nodeGroup: "master"
masterService: ""
roles:
  master: "true"
  ingest: "true"
  data: "true"
{{/* solution to OpenSearch quorum issues by scaling down the cluster and it's quorum to 0, instead of deleting STS that left a quorum deadlock upon re-enabling logging */}}
replicas: {{ get (include "stacklight.replicas" . | fromYaml) "opensearch" }}
{{- if .Values.logging.enabled }}
  {{- if .Values.highAvailabilityEnabled }}
minimumMasterNodes: 2
maxUnavailable: 1
indexTemplate:
  logstash:
    number_of_replicas: 2
    number_of_shards: 2
  notification:
    number_of_replicas: 2
    number_of_shards: 1
  {{- else }}
minimumMasterNodes: 1
maxUnavailable: 0
indexTemplate:
  logstash:
    number_of_replicas: 0
    number_of_shards: 1
  notification:
    number_of_replicas: 0
    number_of_shards: 1
  {{- end }}
{{- else }}
minimumMasterNodes: 0
maxUnavailable: 0
{{- end }}
persistence:
  enabled: true
volumeClaimTemplate:
{{- $componentStorageClass := .Values.storage.componentStorageClasses.elasticsearch | default .Values.storage.componentStorageClasses.opensearch }}
{{- if or .Values.storage.defaultStorageClass $componentStorageClass }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if $componentStorageClass }}
    {{- $storageClass = $componentStorageClass }}
  {{- end }}
  {{- if (eq "-" $storageClass) }}
  storageClassName: ""
  {{- else }}
  storageClassName: "{{ $storageClass }}"
  {{- end }}
{{- end }}
  resources:
    requests:
      storage: {{ .Values.logging.persistentVolumeClaimSize }}
secretMounts: []
networkHost: "0.0.0.0"
{{- $opts := "-Dlog4j2.formatMsgNoLookups=true" }}
{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "elasticsearch" "fallbackService" "opensearch") | fromYaml }}
{{- if and (hasKey $resources.resources "limits") (index (default (dict) $resources.resources.limits) "memory") }}
{{- $memoryMap := include "memStringToMap" $resources.resources.limits.memory | fromYaml }}
{{- $maxMemoryInt := index $memoryMap "memory" }}
{{- $unit := index $memoryMap "unit" }}
{{- $maxMemory := div (mul $maxMemoryInt 4) 5 }}
{{- $memOpts := printf "-Xmx%d%s -Xms%d%s" $maxMemory $unit $maxMemory $unit }}
{{- $opts = printf "%s %s" $opts $memOpts }}
{{- end }}
opensearchJavaOpts: "{{ $opts }}"
extraEnvs:
- name: TAKE_FILE_OWNERSHIP
  value: "true"
config:
  opensearch.yml: |
    cluster.name: opensearch
    network.host: 0.0.0.0
    cluster.max_shards_per_node: 5000
    plugins.security.disabled: true
    path.data: /usr/share/opensearch/data
    compatibility.override_main_response_version: true
  {{- if $logLevel }}
    logger._root.level: {{ $logLevel | quote }}
  {{- end }}
  {{- if .Values.logging.extraConfig }}
    {{ toYaml .Values.logging.extraConfig | nindent 4 }}
  {{- end }}
clusterHealthCheckParams: "{{ .Values.logging.clusterHealthCheckParams }}"
initImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "busybox") | nindent 2 }}
{{- $image := include "stacklight.getImage" (dict "root" . "image" "opensearch") | fromYaml }}
image: {{ index $image "repository" | quote }}
imageTag: {{ index $image "tag" }}
{{ $resources | toYaml }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "elasticsearch" "fallbackService" "opensearch") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "elasticsearch" "fallbackService" "opensearch") }}
{{- end }}
