{{- define "opensearchDashboards" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "critical" "fatal") "component" "opensearchDashboards" | include "stacklight.logLevel" -}}
files:
  opensearch_dashboards.yml:
    server:
      name: opensearch-dashboards
      host: 0.0.0.0
    opensearchDashboards.defaultAppId: dashboard/2d53aa40-ad1f-11e9-9839-052bda0fdf49
    opensearch.hosts: http://opensearch-master:9200
    {{- if $logLevel }}
    logging.root.level: {{ $logLevel | quote }}
    {{- end }}
{{- $extraConfig := mergeOverwrite .Values.logging.dashboardsExtraConfig (get (.Values.elasticsearch | default dict) "kibanaExtraConfig" | default dict) }}
{{- if $extraConfig }}
    {{ toYaml $extraConfig | nindent 4 }}
{{- end }}
plugins:
  enabled: true
  reset: true
dashboardImport:
  enabled: true
  timeout: 600
  defaultIndexPattern: "logstash-index-pattern"
  xpackauth:
    enabled: false
    username: myuser
    password: mypass
  dashboards:
    logs: true
    kubernetes_events: true
    {{- if .Values.openstack.enabled }}
    notifications: true
    {{- end }}

extraVolumeMounts:
- name: custom-dashboards
  mountPath: "/custom-dashboards"
extraVolumes:
- name: custom-dashboards
  configMap:
    name: kibana-custom-dashboards
    optional: true

{{- $resources := include "stacklight.resources" (dict "inTplValues" .Values "service" "kibana" "fallbackService" "opensearchDashboards") | fromYaml }}
{{- $resources := get $resources "resources" }}
{{- if and (hasKey $resources "limits") (index (default (dict) $resources.limits) "memory") }}
{{- $maxMemory := $resources.limits.memory }}
{{- if hasSuffix "Gi" $maxMemory }}
  {{- $maxMemory = mul 1024 ($maxMemory | trimSuffix "Gi" | int64) }}
{{- else if hasSuffix "Mi" $maxMemory }}
  {{- $maxMemory = $maxMemory | trimSuffix "Mi" | int64 }}
{{- end }}
env:
  NODE_OPTIONS: "--max-http-header-size=262144 --max-old-space-size={{ sub $maxMemory 512 }}"
{{- end }}

replicaCount: {{ get (include "stacklight.replicas" . | fromYaml) "opensearchDashboards" }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "opensearchDashboards") | nindent 2 }}

{{- if .Values.exposeLoadBalancers }}
service:
  type: LoadBalancer
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "kibana" "fallbackService" "opensearchDashboards") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "kibana" "fallbackService" "opensearchDashboards") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "kibana" "fallbackService" "opensearchDashboards") }}
{{- end }}
