{{- define "prometheus.defaultScrapeConfigs" -}}
{{- $kubernetesAPIPort := .Values.kubernetesAPIPort }}
{{- if .Values.mke.enabled }}
  {{- $kubernetesAPIPort = .Values.mke.kubernetesAPIPort }}
{{- end }}

helm-controller:
  kubernetes_sd_configs:
  - role: pod
  relabel_configs:
  - source_labels: [__meta_kubernetes_pod_label_app, __meta_kubernetes_pod_container_port_name]
    action: keep
    regex: .*helm-controller;metrics
  - source_labels: [__meta_kubernetes_namespace]
    target_label: controller_namespace
  - source_labels: [__meta_kubernetes_pod_label_app]
    target_label: controller_name
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: controller_pod
  scrape_interval: 30s
  scrape_timeout: 10s

kubernetes-apiservers:

  kubernetes_sd_configs:
    - role: endpoints

  scheme: https
  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  tls_config:
    ca_file: /var/run/secrets/kubernetes.io/serviceaccount/ca.crt
    server_name: kubernetes
  relabel_configs:
    - source_labels: [__meta_kubernetes_namespace, __meta_kubernetes_service_name, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
      action: keep
      regex: default;kubernetes;apiserver;https
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_service_name]
      target_label: service
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_service_label_component]
      target_label: job
  metric_relabel_configs:
  - source_labels: [__name__]
    regex: 'apiserver_request_duration_seconds.+'
    action: drop

kubelet:
  scrape_interval: 30s
  scrape_timeout: 20s
  scheme: https
  tls_config:
    ca_file: /var/run/secrets/kubernetes.io/serviceaccount/ca.crt
    insecure_skip_verify: true
  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token

  kubernetes_sd_configs:
    - role: node

  relabel_configs:
    - target_label: __address__
      replacement: kubernetes.default.svc:443
    - source_labels: [__meta_kubernetes_node_name]
      target_label: __metrics_path__
      replacement: /api/v1/nodes/$1/proxy/metrics
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_node_label_kaas_mirantis_com_machine_name]
      target_label: machine
  metric_relabel_configs:
  - source_labels: [__name__]
    regex: 'kubelet_runtime_operations.*|storage_operation_.+'
    action: drop

cadvisor:
  scrape_interval: 30s
  scrape_timeout: 20s
  scheme: https
  tls_config:
    ca_file: /var/run/secrets/kubernetes.io/serviceaccount/ca.crt
    insecure_skip_verify: true
  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token

  kubernetes_sd_configs:
    - role: node

  relabel_configs:
    - target_label: __address__
      replacement: kubernetes.default.svc:443
    - source_labels: [__meta_kubernetes_node_name]
      target_label: __metrics_path__
      replacement: /api/v1/nodes/$1/proxy/metrics/cadvisor
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node
  metric_relabel_configs:
  # id equals "/" or "/kubepods" or "/kubepods/besteffort" or "/kubepods/burstable" or "/kubepods/guaranteed"
  - source_labels: [__name__, id]
    regex: 'container_.*;/(kubepods(/(besteffort|burstable|guaranteed)|)|)'
    action: drop
  - source_labels: [__name__]
    regex: 'container_(memory_failures_total|tasks_state)'
    action: drop
  - source_labels: [__name__, interface]
    regex: 'container_network.*;eth.*'
    target_label: __tmp_keep
    replacement: true
  - source_labels: [__name__, __tmp_keep]
    regex: 'container_network.*;'
    action: drop
  - regex: __tmp_keep
    action: labeldrop

prometheus-alertmanager:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_service_name]
    regex: prometheus;alertmanager;prometheus-alertmanager
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod

prometheus-coredns:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - kube-system

  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_k8s_app, __meta_kubernetes_endpoint_port_name]
    regex: kube-dns;metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_name]
    target_label: job
  - target_label: endpoint
    replacement: http-metrics

prometheus-grafana:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_endpoint_port_name]
    regex: grafana;service
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - target_label: endpoint
    replacement: service

prometheus-kube-controller-manager:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - kube-system

  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_endpoint_port_name]
    regex: prometheus-kube-controller-manager;http-metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job
  - source_labels: [__meta_kubernetes_node_name]
    target_label: node
  - target_label: endpoint
    replacement: http-metrics

prometheus-kube-scheduler:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - kube-system

  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_endpoint_port_name]
    regex: prometheus-kube-scheduler;http-metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - target_label: endpoint
    replacement: http-metrics

prometheus-kube-state-metrics:
  honor_labels: true
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_pod_label_app, __meta_kubernetes_service_label_component]
    regex: prometheus;kube-state-metrics
    action: keep
  - source_labels: [__meta_kubernetes_service_label_component]
    target_label: job
  metric_relabel_configs:
  - source_labels: [__name__]
    regex: 'kube_pod_[A-Za-z0-9_]+_reason'
    action: drop

prometheus-node-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
    regex: prometheus;node-exporter;metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_component]
    target_label: job
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node

prometheus-server:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name, __meta_kubernetes_service_name]
    regex: prometheus;server;http;prometheus-server
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod


{{- if .Values.prometheusPushgateway.enabled }}
prometheus-pushgateway:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_service_name]
    regex: prometheus;pushgateway;prometheus-pushgateway
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - target_label: endpoint
    replacement: metrics
{{- end }}

{{- if .Values.mke.enabled }}
telegraf-docker-swarm:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 15s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: telegraf-docker-swarm
    action: keep

mke-manager-api:
  metrics_path: /probe
  honor_timestamps: true
  scrape_interval: 15s
  scrape_timeout: 10s
  params:
    module: [http_2xx]
  kubernetes_sd_configs:
    - role: node
  relabel_configs:
    - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
      action: keep
      regex: true
    - source_labels: [__meta_kubernetes_node_address_InternalIP]
      regex: (.+)
      replacement: 'https://${1}:{{ .Values.mke.APIPort }}/_ping'
      target_label: __param_target
    - source_labels: [__param_target]
      target_label: instance
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node

mke-metrics-engine:
  scrape_interval: 30s
  scrape_timeout: 20s
  scheme: https
  tls_config:
    ca_file: /tmp/mkecerts/ca.pem
    cert_file: /tmp/mkecerts/cert.pem
    key_file: /tmp/mkecerts/key.pem
    insecure_skip_verify: true
  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  kubernetes_sd_configs:
    - role: node
  relabel_configs:
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node
    - source_labels: [__meta_kubernetes_node_address_InternalIP]
      regex: (.+)
      replacement: '${1}:12376'
      target_label: __address__
  metric_relabel_configs:
  - source_labels: [__name__]
    regex: "etcd_.*"
    action: drop

mke-metrics-controller:
  scrape_interval: 30s
  scrape_timeout: 20s
  scheme: https
  tls_config:
    ca_file: /tmp/mkecerts/ca.pem
    cert_file: /tmp/mkecerts/cert.pem
    key_file: /tmp/mkecerts/key.pem
    insecure_skip_verify: true
  bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - kube-system
  relabel_configs:
  - source_labels: [__meta_kubernetes_endpoints_name]
    regex: ucp-controller
    action: keep
  - source_labels: [__meta_kubernetes_endpoint_port_name]
    regex: controller
    action: keep
  metric_relabel_configs:
  - source_labels: [__name__]
    regex: "etcd_.*"
    action: drop
  - source_labels: [__name__]
    regex: "ucp_engine_pod_.*"
    action: drop
  - source_labels: [nodeName]
    regex: (.+)
    target_label: node

  {{- if .Values.msrMonitoring.enabled }}
msr-api:
  metrics_path: /probe
  honor_timestamps: true
  scrape_interval: 15s
  scrape_timeout: 10s
  params:
    module: [http_2xx]
  static_configs:
    - targets: {{ .Values.msrMonitoring.msrIPs | toJson }}
  relabel_configs:
    - source_labels: [__address__]
      regex: (.+)
      replacement: 'https://${1}:{{ .Values.mke.APIPort }}/_ping'
      target_label: __param_target
    - source_labels: [__param_target]
      target_label: instance
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
  {{- end }}
{{- end }}

{{- if and .Values.sslCertificateMonitoring.enabled .Values.sslCertificateMonitoring.domains }}
blackbox:
  metrics_path: /probe
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  params:
    module: [http_2xx_verify]
  static_configs:
    - targets: {{ .Values.sslCertificateMonitoring.domains | toJson }}
  relabel_configs:
    - source_labels: [__address__]
      target_label: __param_target
    - source_labels: [__param_target]
      target_label: instance
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
{{- end }}

{{- if and .Values.externalEndpointMonitoring.enabled .Values.externalEndpointMonitoring.domains }}
blackbox-external-endpoint:
  metrics_path: /probe
  honor_timestamps: true
  scrape_interval: 15s
  scrape_timeout: 10s
  params:
  {{- if .Values.externalEndpointMonitoring.verifyCA }}
    module: [http_2xx_verify]
  {{- else }}
    module: [http_2xx]
  {{- end }}
  static_configs:
    - targets: {{ .Values.externalEndpointMonitoring.domains | toJson }}
  relabel_configs:
    - source_labels: [__address__]
      target_label: __param_target
    - source_labels: [__param_target]
      target_label: instance
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115
{{- end }}

{{- if .Values.calico.enabled }}
calico:
  kubernetes_sd_configs:
  - role: pod
    namespaces:
      names:
      - kube-system
  relabel_configs:
    - source_labels: [__meta_kubernetes_pod_label_k8s_app]
      action: keep
      regex: calico-node
    - source_labels: [__address__]
      action: replace
      regex: ([^:]+)(?::\d+)?
      replacement: $1:9091
      target_label: __address__
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node
{{- end }}

{{- if .Values.nginxExporter.enabled }}
prometheus-nginx-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app]
    regex: prometheus-nginx-exporter
    action: keep
  - source_labels: [__meta_kubernetes_endpoint_port_name]
    regex: http-metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job
{{- end }}

{{- if .Values.logging.enabled }}
prometheus-elasticsearch-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app,__meta_kubernetes_endpoint_port_name]
    regex: elasticsearch-exporter;http-metrics
    action: keep
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job

fluentd:
  kubernetes_sd_configs:
    - role: pod
  relabel_configs:
    - source_labels: [__meta_kubernetes_pod_label_app_kubernetes_io_name]
      action: keep
      regex: fluentd-logs
    - source_labels: [__meta_kubernetes_pod_annotation_prometheus_io_path]
      action: replace
      target_label: __metrics_path__
      regex: (.+)
    - source_labels: [__address__, __meta_kubernetes_pod_annotation_prometheus_io_port]
      action: replace
      regex: ([^:]+)(?::\d+)?;(\d+)
      replacement: $1:$2
      target_label: __address__
    - source_labels: [__meta_kubernetes_namespace]
      target_label: namespace
    - source_labels: [__meta_kubernetes_pod_name]
      target_label: pod
    - source_labels: [__meta_kubernetes_pod_node_name]
      target_label: node

prometheus-es-exporter:
  scrape_interval: '1m'
  scrape_timeout: '30s'
  honor_labels: true
  kubernetes_sd_configs:
    - role: service
  relabel_configs:
    - source_labels: [__meta_kubernetes_service_label_app]
      action: keep
      regex: prometheus-es-exporter
{{- end }}

{{- if .Values.alertmanagerSimpleConfig.msteams.enabled }}
prometheus-msteams:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http

  kubernetes_sd_configs:
  - role: endpoints

  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app]
    regex: prometheus-msteams
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
{{- end }}
{{- if not .Values.cortexDev.enabled }}
prometheus-relay:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_service_name]
    regex: prometheus;relay;prometheus-relay
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - target_label: endpoint
    replacement: metrics
{{- end }}
{{- if .Values.alertmanagerSimpleConfig.salesForce.enabled }}
sf-notifier:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
    - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app]
    regex: sf-notifier
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job
{{- end }}

{{- if .Values.alertmanagerSimpleConfig.serviceNow.enabled }}
alertmanager-webhook-servicenow:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
    - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app]
    regex: alertmanager-webhook-servicenow
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_jobLabel]
    target_label: job
{{- end }}

{{- $externalFQDNs := or (not (empty .Values.openstack.externalFQDN)) .Values.openstack.externalFQDNs.enabled }}
{{- if .Values.openstack.enabled }}
  {{- if $externalFQDNs }}
openstack-blackbox-ext:
  metrics_path: /probe
  kubernetes_sd_configs:
  - role: ingress
    namespaces:
      names:
      - openstack
  relabel_configs:
  - source_labels: [__meta_kubernetes_ingress_scheme, __meta_kubernetes_ingress_name, __address__]
    regex: 'https;[^;]+-namespace-fqdn;[^;]*\.[^;]*'
    action: keep
  - source_labels: [__meta_kubernetes_ingress_host]
    regex: '([^\.]+)(?:\..*|$)'
    replacement: '$1'
    target_label: service_name
  - source_labels: [__address__]
    target_label: instance
  - source_labels: [__meta_kubernetes_ingress_scheme, instance]
    regex: '([^;]+);([^;]+)'
    replacement: '$1://$2'
    target_label: __param_target
  - source_labels: [__meta_kubernetes_ingress_scheme, instance]
    regex: '([^;]+);(novncproxy.[^;]+)'
    replacement: '$1://$2/vnc_auto.html'
    target_label: __param_target
  - target_label: __param_module
  {{- if .Values.openstack.insecure.external }}
    replacement: http_openstack_insecure
  {{- else }}
    replacement: http_openstack
  {{- end }}
  - source_labels: [__param_module]
    target_label: blackbox_probe_module
  - target_label: __address__
    replacement: prometheus-blackbox-exporter:9115
  {{- end }}

telegraf-openstack:
  scrape_interval: '{{ .Values.openstack.telegraf.interval }}'
  scrape_timeout: '30s'
  honor_labels: true
  kubernetes_sd_configs:
    - role: service
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: telegraf-openstack
    action: keep

prometheus-libvirt-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 15s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: prometheus-libvirt-exporter
    action: keep
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: host

prometheus-memcached-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - openstack
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
    regex: prometheus_memcached_exporter;metrics;metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: cluster
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod

prometheus-mysql-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - openstack
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
    regex: prometheus-mysql-exporter;metrics;metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: cluster
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod

openstack-ingress-controller:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - openstack
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_endpoint_port_name]
    regex: ingress_exporter;metrics
    action: keep

  {{- if and (not .Values.tungstenFabricMonitoring.enabled) (.Values.openstack.arpingCheck.enabled) }}
telegraf-ds-arping-check:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 15s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: telegraf-ds-arping-check
    action: keep
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  {{- end }}
{{- end }}

{{- if or .Values.openstack.enabled .Values.tungstenFabricMonitoring.enabled }}
prometheus-rabbitmq-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
  {{- if .Values.openstack.enabled }}
      - openstack
  {{- end }}
  {{- if .Values.tungstenFabricMonitoring.enabled }}
      - tf
  {{- end }}
  metric_relabel_configs:
  - regex: 'self'
    action: labeldrop
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_application, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
    regex: prometheus_rabbitmq_exporter;metrics;metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
{{- end }}

{{- if .Values.tungstenFabricMonitoring.enabled }}
rabbitmq-operator-metrics:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - tf
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_name, __meta_kubernetes_endpoint_port_name]
    regex: rabbitmq-operator;cr-metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
{{- end }}

{{- if .Values.ceph.enabled }}
prometheus-ceph:
  honor_timestamps: true
  honor_labels: false
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - rook-ceph
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_endpoint_port_name]
    regex: rook-ceph-mgr;http-metrics
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_service_label_rook_cluster]
    target_label: rook_cluster
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_service_label_app]
    target_label: job
{{- end }}

{{- if .Values.ipmiExporter.enabled }}
{{- $ipmiHosts := .Values.ipmiExporter.hosts }}
{{- $ipmiHosts = include "ipmiExporter.hostsToModules" $ipmiHosts | fromYaml }}
  {{- range $module := keys $ipmiHosts | sortAlpha }}
    {{- $moduleSplit := split "_" $module }}
    {{- $namespace := $moduleSplit._0 }}
    {{- $host := $moduleSplit._1 }}
ipmi-{{ $module }}:
  params:
    module: ['{{ $module }}']
  scrape_interval: 1m
  scrape_timeout: 30s
  metrics_path: /ipmi
  scheme: http
  static_configs:
  - targets:
    - {{ get $ipmiHosts $module }}
    labels:
      ipmi_namespace: {{ $namespace }}
      ipmi_host: {{ $host }}
  relabel_configs:
  - source_labels: [__address__]
    separator: ;
    regex: (.*)
    target_label: __param_target
    replacement: ${1}
    action: replace
  - source_labels: [__param_target]
    separator: ;
    regex: (.*)
    target_label: instance
    replacement: ${1}
    action: replace
  - separator: ;
    regex: .*
    target_label: __address__
    replacement: ipmi-exporter:9200
    action: replace
  {{- end }}
{{- end }}

{{- if .Values.ironic.enabled }}
ironic:
  scrape_interval: '30s'
  scrape_timeout: '15s'
  honor_labels: true
  kubernetes_sd_configs:
  - role: service
    namespaces:
      names:
      - kaas
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_service_port_name]
    regex: ironic-kaas-bm;ironic-telemetry
    action: keep
{{- end }}

{{- if eq .Values.provider "BareMetal" }}
telegraf-ds-smart:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 15s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: telegraf-ds-smart
    action: keep
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
{{- end }}

{{- if .Values.telemetry.telemeterServer.enabled }}
telemeter-federate:
  scrape_interval: '1m'
  scrape_timeout: '30s'
  honor_labels: true
  metrics_path: '/federate'
  params:
    'match[]':
      - '{__name__=~".+"}'
  kubernetes_sd_configs:
    - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_endpoint_port_name]
    regex: telemeter-server;internal
    action: keep

telemeter-server:
  scrape_interval: '30s'
  scrape_timeout: '15s'
  honor_labels: true
  kubernetes_sd_configs:
    - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name,__meta_kubernetes_endpoint_port_name]
    regex: telemeter-server;internal
    action: keep
{{- end }}

{{- if .Values.telemetry.telemeterClient.enabled }}
telemeter-client:
  scrape_interval: '30s'
  scrape_timeout: '15s'
  honor_labels: true
  kubernetes_sd_configs:
    - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: telemeter-client
    action: keep
{{- end }}

kubernetes-master-api:
  metrics_path: /probe
  honor_timestamps: true
  scrape_interval: 15s
  scrape_timeout: 10s
  params:
    module: [http_2xx]
  kubernetes_sd_configs:
    - role: node
  relabel_configs:
    - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
      action: keep
      regex: true
    - source_labels: [__meta_kubernetes_node_address_InternalIP]
      regex: (.+)
      replacement: 'https://${1}:{{ $kubernetesAPIPort }}/healthz'
      target_label: __param_target
    - source_labels: [__meta_kubernetes_node_name]
      target_label: node
    - source_labels: [__param_target]
      target_label: instance
    - source_labels: [__param_module]
      target_label: blackbox_probe_module
    - target_label: __address__
      replacement: prometheus-blackbox-exporter:9115

{{- if .Values.mke.enabled }}
prometheus-etcd:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  kubernetes_sd_configs:
  - role: node
  scheme: https
  tls_config:
    ca_file: /tmp/mkecerts/ca.pem
    cert_file: /tmp/mkecerts/cert.pem
    insecure_skip_verify: true
    key_file: /tmp/mkecerts/key.pem
    server_name: ucp-controller.kube-system.svc.cluster.local
  relabel_configs:
  - source_labels: [__meta_kubernetes_node_labelpresent_node_role_kubernetes_io_master]
    regex: true
    action: keep
  - source_labels: [__address__]
    action: replace
    regex: ([^:]+)(?::\d+)?
    replacement: $1:12379
    target_label: __address__
  - source_labels: [__meta_kubernetes_node_name]
    target_label: node
{{- end }}

{{- $iamTLSEnabled := and .Values.iam.enabled .Values.iam.tls.enabled }}
{{- $telemeterServerTLSEnabled := and .Values.telemetry.telemeterServer.enabled .Values.telemetry.telemeterServer.tls.enabled }}
{{- if or .Values.mccTLSCertificateMonitoringEnabled $iamTLSEnabled $telemeterServerTLSEnabled }}
mcc-blackbox:
  metrics_path: /probe
  kubernetes_sd_configs:
  - role: service
    namespaces:
      names:
      {{- if .Values.mccTLSCertificateMonitoringEnabled }}
      - kaas
      {{- end }}
      {{- if or $iamTLSEnabled $telemeterServerTLSEnabled }}
      - stacklight
      {{- end }}
  - role: endpoints
    namespaces:
      names:
      {{- if .Values.mccTLSCertificateMonitoringEnabled }}
      - kaas
      {{- end }}
      {{- if or $iamTLSEnabled $telemeterServerTLSEnabled }}
      - stacklight
      {{- end }}
  relabel_configs:
  # <or filter>
  - source_labels: [__meta_kubernetes_service_port_name, __meta_kubernetes_service_cluster_ip]
    regex: '(?:web|https);\d+\.\d+\.\d+\.\d+'
    replacement: 'yes'
    target_label: scrape
  - source_labels: [__meta_kubernetes_endpoint_port_name, __meta_kubernetes_endpoint_ready]
    regex: '(?:web|https);true'
    replacement: 'yes'
    target_label: scrape
  - source_labels: [scrape]
    regex: 'yes'
    action: keep
  - action: labeldrop
    regex: 'scrape'
  # </or filter>
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service_name
  - source_labels: [__meta_kubernetes_endpoint_address_target_kind, __meta_kubernetes_endpoint_address_target_name]
    regex: 'Pod;([^;]+)'
    replacement: '$1'
    target_label: pod
  - source_labels: [__address__]
    target_label: instance
  - source_labels: [__meta_kubernetes_service_port_name, instance]
    regex: '(?:https|web);([^;]+)'
    replacement: '$1'
    target_label: __param_target
  - source_labels: [__meta_kubernetes_endpoint_port_name, instance]
    regex: '(?:https|web);([^;]+)'
    replacement: '$1'
    target_label: __param_target
  - target_label: __param_module
    replacement: tls
  - source_labels: [__param_module]
    target_label: blackbox_probe_module
  - target_label: __address__
    replacement: prometheus-blackbox-exporter:9115
{{- end }}

{{- if .Values.kaasExporterEnabled }}
kaas-exporter:
  scrape_interval: '60s'
  scrape_timeout: '30s'
  honor_labels: true
  kubernetes_sd_configs:
    - role: service
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: kaas-exporter
    action: keep
  metric_relabel_configs:
  - source_labels: [__name__, cluster_id]
    regex: "kaas_machines_(ready|requested);(.+)"
    replacement: $2
    target_label: exported_cluster_id
{{- end }}

{{- if .Values.tungstenFabricMonitoring.enabled }}
tf-cassandra-jmx-exporter:
  honor_timestamps: true
  scrape_interval: 30s
  scrape_timeout: 10s
  metrics_path: /metrics
  scheme: http
  kubernetes_sd_configs:
  - role: endpoints
    namespaces:
      names:
      - tf
  relabel_configs:
  - source_labels:
    - __meta_kubernetes_service_label_app
    - __meta_kubernetes_service_label_k8s_app
    - __meta_kubernetes_endpoint_port_name
    regex: cassandracluster;exporter-cassandra-jmx;promjmx
    action: keep
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_label_cassandracluster]
    target_label: cluster
  - source_labels: [__meta_kubernetes_pod_label_cassandraclusters_db_orange_com_dc]
    target_label: datacenter
  - source_labels: [__meta_kubernetes_pod_label_cassandraclusters_db_orange_com_rack]
    target_label: rack

tf-redis:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - action: keep
    source_labels: [__meta_kubernetes_service_label_name, __meta_kubernetes_service_label_redis, __meta_kubernetes_endpoint_port_name]
    regex: 'tf-redis;tf-redis;exporter'
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_pod_label_redis]
    target_label: cluster

tf-zookeeper:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - action: keep
    source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_headless, __meta_kubernetes_endpoint_port_name]
    regex: 'tf-zookeeper[^;]*;true;tcp-metrics'
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_pod_label_app]
    target_label: cluster

tf-control:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - action: keep
    source_labels: [__meta_kubernetes_service_name]
    regex: 'prometheus-tf-controller-exporter'
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node

tf-kafka-jmx:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - action: keep
    source_labels: [__meta_kubernetes_service_label_app, __meta_kubernetes_service_label_component, __meta_kubernetes_endpoint_port_name]
    regex: 'tf-kafka;kafka-broker;http-metrics'
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  - source_labels: [__meta_kubernetes_pod_label_app]
    target_label: cluster

tf-vrouter:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - action: keep
    source_labels: [__meta_kubernetes_service_name]
    regex: 'prometheus-tf-vrouter-exporter'
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
{{- end }}

postgresql:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: patroni(?:-[0-9a-f]+)?-readonly
    action: keep
  - source_labels: [__address__]
    action: replace
    regex: ([^:]+)(?::\d+)?
    replacement: $1:9187
    target_label: __address__
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_label_release]
    target_label: cluster
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node
  metric_relabel_configs:
  # `server` label is irrelevant when exporter is co-located in pod, due to reporting localhost
  - regex: server
    action: labeldrop

patroni:
  kubernetes_sd_configs:
  - role: endpoints
  relabel_configs:
  - source_labels: [__meta_kubernetes_service_name]
    regex: patroni(?:-[0-9a-f]+)?-readonly
    action: keep
  - source_labels: [__address__]
    action: replace
    regex: ([^:]+)(?::\d+)?
    replacement: $1:9547
    target_label: __address__
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_label_release]
    target_label: cluster
  - source_labels: [__meta_kubernetes_pod_name]
    target_label: pod
  - source_labels: [__meta_kubernetes_pod_node_name]
    target_label: node

stacklight-generic:
  metrics_path: /metrics
  kubernetes_sd_configs:
  - role: endpoints
  - role: service
  relabel_configs:
  # <or filter>
  # "generic.stacklight.mirantis.com/scrape-port": "8080"
  - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_port]
    regex: 'true'
    replacement: 'yes'
    target_label: scrape
  # "generic.stacklight.mirantis.com/scrape-path": "/custom_metrics"
  - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_path]
    regex: 'true'
    replacement: 'yes'
    target_label: scrape
  # "generic.stacklight.mirantis.com/scrape-scheme": "https"
  - source_labels: [__meta_kubernetes_service_annotationpresent_generic_stacklight_mirantis_com_scrape_scheme]
    regex: 'true'
    replacement: 'yes'
    target_label: scrape
  - source_labels: [scrape]
    regex: 'yes'
    action: keep
  - action: labeldrop
    regex: 'scrape'
  # </or filter>
  # <k8s resource names>
  - source_labels: [__meta_kubernetes_namespace]
    target_label: namespace
  - source_labels: [__meta_kubernetes_service_name]
    target_label: service_name
  - source_labels: [__meta_kubernetes_endpoint_address_target_kind, __meta_kubernetes_endpoint_address_target_name]
    regex: 'Pod;([^;]+)'
    replacement: '$1'
    target_label: pod
  # </k8s resource names>
  # <scrape config through annotations>
  - source_labels: [__meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_scheme]
    regex: '(.+)'
    target_label: __scheme__
  - source_labels: [__address__, __meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_port]
    regex: '([^:]+)(?::\d+)?;(\d+)'
    replacement: $1:$2
    target_label: __address__
  - source_labels: [__meta_kubernetes_service_annotation_generic_stacklight_mirantis_com_scrape_path]
    regex: '(.+)'
    replacement: '$1'
    target_label: __metrics_path__
  # </scrape config through annotations>
{{- end }}

{{- define "prometheus.scrapeConfigs" -}}
{{- $defaultScrapeConfigs := include "prometheus.defaultScrapeConfigs" . | fromYaml }}
{{- $customScrapeConfigs := .Values.prometheusServer.customScrapeConfigs }}
{{- range $defaultScrapeConfigName := keys $defaultScrapeConfigs }}
  {{- $_ := unset $customScrapeConfigs $defaultScrapeConfigName }}
{{- end }}
{{- merge $defaultScrapeConfigs $customScrapeConfigs | toYaml }}
{{- end }}
