{{- define "sfReporter.queries" -}}
  {{- if .Values.openstack.enabled }}
compute_nodes:
  title: 'Compute Nodes'
  expr: 'avg(sum(openstack_nova_services{binary=~"nova.compute"}) by (instance))'
nova_vm_all:
  title: 'Total VM number'
  expr: 'avg_over_time(total:openstack_nova_instance_all[1d])'
nova_api:
  title: 'Nova API'
  expr: 'avg(avg_over_time(openstack_api_check_status{service_name="nova"}[24h]))'
vcpu_used:
  title: 'vCPU Used'
  expr: 'avg(sum(avg_over_time(openstack_nova_used_vcpus[24h])) by (instance))'
vcpu_free:
  title: 'vCPU Free'
  expr: 'avg(sum(avg_over_time(openstack_nova_free_vcpus[24h])) by (instance))'
cinder_api:
  title: 'Cinder API'
  expr: 'avg(avg_over_time(openstack_api_check_status{service_name="cinderv2"}[24h]))'
nova_vm_failed:
  title: 'Failed VM number'
  expr: 'avg_over_time(total:openstack_nova_instance_failed[1d])'
vstorage_free:
  title: 'vStorage Free'
  expr: 'avg(sum(avg_over_time(openstack_nova_free_disk[24h])) by (instance))'
instances:
  title: 'Instances'
  expr: 'avg(sum(avg_over_time(openstack_nova_instances{state="active"}[24h])) by (instance))'
vstorage_used:
  title: 'vStorage Used'
  expr: 'avg(sum(avg_over_time(openstack_nova_used_disk[24h])) by (instance))'
glance_api:
  title: 'Glance API'
  expr: 'avg(avg_over_time(openstack_api_check_status{service_name="glance"}[24h]))'
vram_free:
  title: 'vRAM Free'
  expr: 'avg(sum(avg_over_time(openstack_nova_free_ram[24h])) by (instance))'
keystone_api:
  title: 'Keystone API'
  expr: 'avg(avg_over_time(openstack_api_check_status{service_name="keystone"}[24h]))'
kpi_downtime:
  title: 'KPI Downtime'
  expr: '1 - avg_over_time(total:openstack_nova_instance_failed[1d]) / avg_over_time(total:openstack_nova_instance_all[1d])'
neutron_api:
  title: 'Neutron API'
  expr: 'avg(avg_over_time(openstack_api_check_status{service_name="neutron"}[24h]))'
vram_used:
  title: 'vRAM Used'
  expr: 'avg(sum(avg_over_time(openstack_nova_used_ram[24h])) by (instance))'
tenants:
  title: 'Tenants'
  expr: 'avg(sum(avg_over_time(openstack_keystone_tenants_total[24h])) by (instance))'
    {{- if .Values.logging.enabled }}
compute_instance_create_start:
  title: 'VM creation start'
  expr: 'sum(compute_instance_create_start_event_doc_count)'
compute_instance_create_end:
  title: 'VM creation end'
  expr: 'sum(compute_instance_create_end_event_doc_count)'
compute_instance_create_error:
  title: 'VM creation error'
  expr: 'sum(compute_instance_create_error_event_doc_count)'
    {{- end }}
  {{- end }}
  {{- if .Values.mke.enabled }}
total_cluster_nodes:
  title: 'Total Cluster Nodes'
  expr: 'count(docker_swarm_node_ready)'
total_containers:
  title: 'Total Containers'
  expr: 'sum(ucp_engine_containers)'
   {{- if .Values.msrMonitoring.enabled }}
msr_api:
  title: 'MSR API'
  expr: 'avg_over_time(api:probe_sucess:avg5m:for5m:ceil:avg5m:floor{job="msr-api"}[24h]) * 100'
   {{- end }}
mke_api:
  title: 'MKE API'
  expr: 'avg_over_time(api:probe_sucess:avg5m:for5m:ceil:avg5m:floor{job="mke-manager-api"}[24h]) * 100'
kubernetes_api:
  title: 'Kubernetes API'
  expr: 'avg_over_time(api:probe_sucess:avg5m:for5m:ceil:avg5m:floor{job="kubernetes-master-api"}[24h]) * 100'
vcpu_free:
  title: 'vCPU Free'
  expr: 'round(sum(ucp_engine_num_cpu_cores) - sum(ucp_engine_container_cpu_percent) / 100)'
vcpu_used:
  title: 'vCPU Used'
  expr: 'round(sum(ucp_engine_container_cpu_percent) / 100)'
vram_free:
  title: 'vRAM Free'
  expr: 'sum(ucp_engine_memory_total_bytes) - sum(ucp_engine_container_memory_usage_bytes)'
vram_used:
  title: 'vRAM Used'
  expr: 'sum(ucp_engine_container_memory_usage_bytes)'
vstorage_free:
  title: 'vStorage Free'
  expr: 'sum(ucp_engine_disk_free_bytes)'
vstorage_used:
  title: 'vStorage Used'
  expr: 'sum(ucp_engine_disk_total_bytes) - sum(ucp_engine_disk_free_bytes)'
  {{- end }}
{{- end }}
{{- define "sfReporter" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "sfReporter" | include "stacklight.logLevel" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "sfReporter") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "sfReporter") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "sfReporter") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "sfReporter") }}
{{ $auth := .Values.sfReporter.salesForceAuth }}
{{- if empty $auth }}
  {{ $auth = .Values.alertmanagerSimpleConfig.salesForce.auth }}
{{- end }}
httpProxyDiscovery:
  enabled: {{ .Values.global.proxy.enabled }}
  secretName: {{ .Values.global.proxy.secretName }}
  checksum: {{ .Values.global.proxy.hash }}
env:
  {{- if not (empty .Values.clusterId) }}
  CLUSTER_ID: {{ .Values.clusterId }}
  {{- end }}
  PROMETHEUS_URL: "http://prometheus-server.stacklight.svc"
  CONFIG_PATH: "/opt/sf-reporter/config/config.ini"
  SFDC_AUTH_URL: {{ $auth.url }}
  SFDC_USERNAME: {{ $auth.username }}
  SFDC_PASSWORD: {{ $auth.password }}
  SFDC_ORGANIZATION_ID: {{ $auth.organization_id }}
  SFDC_ENVIRONMENT_ID: {{ $auth.environment_id }}
  SFDC_SANDBOX_ENABLED: {{ $auth.sandbox_enabled | default "false" }}
{{- if $logLevel }}
  DEFAULT_LOGGER_LEVEL: {{ $logLevel }}
{{- end }}
  {{- $queries := include "sfReporter.queries" . | fromYaml }}
queries:
  {{ mergeOverwrite $queries .Values.sfReporter.extraQueries | toYaml | nindent 2 }}
  {{- if .Values.sfReporter.cronjob }}
cronjob:
  {{ toYaml .Values.sfReporter.cronjob | nindent 2 }}
  {{- end }}
{{- end -}}
